from flask import Flask, jsonify
from flask_cors import CORS
import toml

from db import db
from game_api import game

app = Flask(__name__)
CORS(app)

with open("secrets.toml") as infile:
    secrets = toml.load(infile)
app.secret_key = secrets["secret_key"]
app.config["GROUP_PASS"] = secrets["group_pass"]
app.config["GOOGLE_API_KEY"] = secrets["google_api_key"]
app.config["SQLALCHEMY_DATABASE_URI"] = secrets["db_uri"]
app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = False

app.register_blueprint(game, url_prefix="/game")

db.init_app(app)
db.create_all(app=app)


@app.route("/")
def version():
    return jsonify({"version": "1", "status": "healthy"})


if __name__ == "__main__":
    app.run("0.0.0.0", 5000, debug=True)
